Package: DegNorm
Type: Package
Title: DegNorm: degradation normalization for RNA-seq data
Version: 1.16.0
Date: 2024-03-26
Author: Bin Xiong and Ji-Ping Wang
Maintainer: Ji-Ping Wang <jzwang@northwestern.edu>
biocViews: RNASeq, Normalization, GeneExpression, Alignment,Coverage,
        DifferentialExpression, BatchEffect,Software,Sequencing,
        ImmunoOncology, QualityControl, DataImport
Description: This package performs degradation normalization in bulk RNA-seq data to improve differential expression analysis accuracy.
License: LGPL (>= 3)
Depends: R (>= 4.0.0), methods
Imports: Rcpp (>= 1.0.2),GenomicFeatures, txdbmaker, parallel, foreach,
        S4Vectors, doParallel, Rsamtools (>= 1.31.2),
        GenomicAlignments, heatmaply, data.table, stats, ggplot2,
        GenomicRanges, IRanges, plyr, plotly, utils,viridis
LinkingTo: Rcpp, RcppArmadillo,S4Vectors,IRanges
NeedsCompilation: yes
Packaged: 2024-10-30 00:24:15 UTC; biocbuild
Suggests: knitr,rmarkdown,formatR
VignetteBuilder: knitr
BugReports: https://github.com/jipingw/DegNorm/issues
git_url: https://git.bioconductor.org/packages/DegNorm
git_branch: RELEASE_3_20
git_last_commit: c2580b9
git_last_commit_date: 2024-10-29
Repository: Bioconductor 3.20
Date/Publication: 2024-10-29
