Package: DegNorm
Type: Package
Title: DegNorm: degradation normalization for RNA-seq data
Version: 1.22.0
Date: 2025-08-11
Authors@R: 
    person("bin", "Xiong",
        email = "binxiong2012@u.northwestern.edu",
        role = c("aut"))
    person("Ji-Ping", "Wang",
        email = "jzwang@northwestern.edu",
        role = c("aut", "cre"),
        comment = c(ORCID="0000-0002-8398-939X"))
biocViews: RNASeq, Normalization, GeneExpression, Alignment,Coverage,
        DifferentialExpression, BatchEffect,Software,Sequencing,
        ImmunoOncology, QualityControl, DataImport
Description: This package performs degradation normalization in bulk RNA-seq data to improve differential expression analysis accuracy. It provides estimates for each gene within each sample.
License: LGPL (>= 3)
Depends: R (>= 4.0.0), methods
Imports: Rcpp (>= 1.0.2),GenomicFeatures, txdbmaker, parallel, foreach,
        S4Vectors, doParallel, Rsamtools (>= 1.31.2),
        GenomicAlignments, heatmaply, data.table, stats, ggplot2,
        GenomicRanges, IRanges, plyr, plotly, utils,viridis
LinkingTo: Rcpp, RcppArmadillo,S4Vectors,IRanges
NeedsCompilation: yes
Packaged: 2026-04-28 21:43:24 UTC; biocbuild
Suggests: knitr,rmarkdown,formatR
VignetteBuilder: knitr
BugReports: https://github.com/jipingw/DegNorm/issues
git_url: https://git.bioconductor.org/packages/DegNorm
git_branch: RELEASE_3_23
git_last_commit: da6503c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Author: Ji-Ping Wang [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8398-939X>)
Maintainer: Ji-Ping Wang <jzwang@northwestern.edu>
