useDynLib(DegNorm, .registration=TRUE)
importFrom(Rcpp, evalCpp)
import(methods)
importFrom(GenomicAlignments,GAlignments,readGAlignmentPairs,readGAlignments)
importFrom(GenomicFeatures,pcoverageByTranscript,exonsBy)
importFrom(txdbmaker,makeTxDbFromGFF)
importFrom(Rsamtools,ScanBamParam,BamFile,indexBam,scanBamFlag,testPairedEndBam)
importFrom(IRanges,RleList, extractList,IntegerList,stack)
importFrom(heatmaply,heatmaply)
importFrom(GenomicRanges,findOverlaps,reduce,seqinfo,seqnames,strand)
importFrom(S4Vectors, countQueryHits, endoapply, queryHits, runValue)
importFrom(ggplot2,aes, facet_grid, geom_boxplot, geom_line, ggplot, 
    stat_boxplot, theme,theme_classic, theme_light, xlab, ylab, ylim,
    scale_color_manual)
importFrom(doParallel,registerDoParallel,stopImplicitCluster)
importFrom(foreach, "%dopar%", foreach)
importFrom(parallel, detectCores,makeCluster,stopCluster)
importFrom(plotly,plot_ly,subplot)
importFrom(data.table, data.table)
importFrom(stats, setNames,cor,median)
importFrom(utils, globalVariables)
importFrom(plyr,mutate)
import(viridis)
## Export functions
export(degnorm, 
    read_coverage_batch,
    summary_CoverageClass,
    summary_DegNormClass,
    plot_heatmap,
    plot_corr,
    plot_coverage,
    plot_boxplot)



