# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.bin_drop <- function(bin_size, bin_number, res_std_max) {
    .Call(`_DegNorm_bin_drop`, bin_size, bin_number, res_std_max)
}

.NMFCPP <- function(f, loop) {
    .Call(`_DegNorm_NMFCPP`, f, loop)
}

.optiNMFCPP <- function(f, normFactor, loop, baseline) {
    .Call(`_DegNorm_optiNMFCPP`, f, normFactor, loop, baseline)
}

.optiNMFCPP_grid <- function(f, normFactor, loop, grid_size) {
    .Call(`_DegNorm_optiNMFCPP_grid`, f, normFactor, loop, grid_size)
}

